@@ -1,4 +1,6 @@
-# Copyright 2018 Google LLC
+# -*- coding: utf-8 -*-
+#
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,7 +14,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+
 from __future__ import absolute_import
+import sys
+import warnings
 
 from dialogflow_v2 import types
 from dialogflow_v2.gapic import agents_client
@@ -24,6 +29,15 @@ from dialogflow_v2.gapic import session_entity_types_client
 from dialogflow_v2.gapic import sessions_client
 
 
+if sys.version_info[:2] == (2, 7):
+    message = (
+        "A future version of this library will drop support for Python 2.7."
+        "More details about Python 2 support for Google Cloud Client Libraries"
+        "can be found at https://cloud.google.com/python/docs/python2-sunset/"
+    )
+    warnings.warn(message, DeprecationWarning)
+
+
 class AgentsClient(agents_client.AgentsClient):
     __doc__ = agents_client.AgentsClient.__doc__
     enums = enums
@@ -44,8 +58,7 @@ class IntentsClient(intents_client.IntentsClient):
     enums = enums
 
 
-class SessionEntityTypesClient(
-        session_entity_types_client.SessionEntityTypesClient):
+class SessionEntityTypesClient(session_entity_types_client.SessionEntityTypesClient):
     __doc__ = session_entity_types_client.SessionEntityTypesClient.__doc__
     enums = enums
 
@@ -56,12 +69,12 @@ class SessionsClient(sessions_client.SessionsClient):
 
 
 __all__ = (
-    'enums',
-    'types',
-    'AgentsClient',
-    'ContextsClient',
-    'EntityTypesClient',
-    'IntentsClient',
-    'SessionEntityTypesClient',
-    'SessionsClient',
+    "enums",
+    "types",
+    "AgentsClient",
+    "ContextsClient",
+    "EntityTypesClient",
+    "IntentsClient",
+    "SessionEntityTypesClient",
+    "SessionsClient",
 )
