@@ -1,4 +1,6 @@
-# Copyright 2018 Google LLC
+# -*- coding: utf-8 -*-
+#
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 """Accesses the google.cloud.dialogflow.v2 SessionEntityTypes API."""
 
 import functools
@@ -18,9 +21,11 @@ import pkg_resources
 import warnings
 
 from google.oauth2 import service_account
+import google.api_core.client_options
 import google.api_core.gapic_v1.client_info
 import google.api_core.gapic_v1.config
 import google.api_core.gapic_v1.method
+import google.api_core.gapic_v1.routing_header
 import google.api_core.grpc_helpers
 import google.api_core.page_iterator
 import google.api_core.path_template
@@ -39,13 +44,14 @@ from dialogflow_v2.proto import intent_pb2
 from dialogflow_v2.proto import intent_pb2_grpc
 from dialogflow_v2.proto import session_entity_type_pb2
 from dialogflow_v2.proto import session_entity_type_pb2_grpc
+from dialogflow_v2.proto import validation_result_pb2
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2
 from google.protobuf import field_mask_pb2
 from google.protobuf import struct_pb2
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
-    'dialogflow', ).version
+
+_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class SessionEntityTypesClient(object):
@@ -56,20 +62,24 @@ class SessionEntityTypesClient(object):
     actionable data for your application.
 
     Session entity types are referred to as **User** entity types and are
-    entities that are built for an individual user such as
-    favorites, preferences, playlists, and so on. You can redefine a session
-    entity type at the session level.
+    entities that are built for an individual user such as favorites,
+    preferences, playlists, and so on. You can redefine a session entity
+    type at the session level.
 
-    For more information about entity types, see the
-    `Dialogflow documentation <https://dialogflow.com/docs/entities>`__.
+    Session entity methods do not work with Google Assistant integration.
+    Contact Dialogflow support if you need to use session entities with
+    Google Assistant integration.
+
+    For more information about entity types, see the `Dialogflow
+    documentation <https://cloud.google.com/dialogflow/docs/entities-overview>`__.
     """
 
-    SERVICE_ADDRESS = 'dialogflow.googleapis.com:443'
+    SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
 
     # The name of the interface for this client. This is the key used to
     # find the method configuration in the client_config dictionary.
-    _INTERFACE_NAME = 'google.cloud.dialogflow.v2.SessionEntityTypes'
+    _INTERFACE_NAME = "google.cloud.dialogflow.v2.SessionEntityTypes"
 
     @classmethod
     def from_service_account_file(cls, filename, *args, **kwargs):
@@ -85,9 +95,8 @@ class SessionEntityTypesClient(object):
         Returns:
             dialogflow_v2.SessionEntityTypesClient: The constructed client.
         """
-        credentials = service_account.Credentials.from_service_account_file(
-            filename)
-        kwargs['credentials'] = credentials
+        credentials = service_account.Credentials.from_service_account_file(filename)
+        kwargs["credentials"] = credentials
         return cls(*args, **kwargs)
 
     from_service_account_json = from_service_account_file
@@ -96,7 +105,7 @@ class SessionEntityTypesClient(object):
     def session_path(cls, project, session):
         """Return a fully-qualified session string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/sessions/{session}',
+            "projects/{project}/agent/sessions/{session}",
             project=project,
             session=session,
         )
@@ -105,18 +114,21 @@ class SessionEntityTypesClient(object):
     def session_entity_type_path(cls, project, session, entity_type):
         """Return a fully-qualified session_entity_type string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/sessions/{session}/entityTypes/{entity_type}',
+            "projects/{project}/agent/sessions/{session}/entityTypes/{entity_type}",
             project=project,
             session=session,
             entity_type=entity_type,
         )
 
-    def __init__(self,
-                 transport=None,
-                 channel=None,
-                 credentials=None,
-                 client_config=session_entity_types_client_config.config,
-                 client_info=None):
+    def __init__(
+        self,
+        transport=None,
+        channel=None,
+        credentials=None,
+        client_config=None,
+        client_info=None,
+        client_options=None,
+    ):
         """Constructor.
 
         Args:
@@ -146,15 +158,35 @@ class SessionEntityTypesClient(object):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
+                Client options used to set user options on the client. API Endpoint
+                should be set through client_options.
         """
         # Raise deprecation warnings for things we want to go away.
-        if client_config:
-            warnings.warn('The `client_config` argument is deprecated.',
-                          PendingDeprecationWarning)
+        if client_config is not None:
+            warnings.warn(
+                "The `client_config` argument is deprecated.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+        else:
+            client_config = session_entity_types_client_config.config
+
         if channel:
             warnings.warn(
-                'The `channel` argument is deprecated; use '
-                '`transport` instead.', PendingDeprecationWarning)
+                "The `channel` argument is deprecated; use " "`transport` instead.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+
+        api_endpoint = self.SERVICE_ADDRESS
+        if client_options:
+            if type(client_options) == dict:
+                client_options = google.api_core.client_options.from_dict(
+                    client_options
+                )
+            if client_options.api_endpoint:
+                api_endpoint = client_options.api_endpoint
 
         # Instantiate the transport.
         # The transport is responsible for handling serialization and
@@ -163,25 +195,27 @@ class SessionEntityTypesClient(object):
             if callable(transport):
                 self.transport = transport(
                     credentials=credentials,
-                    default_class=session_entity_types_grpc_transport.
-                    SessionEntityTypesGrpcTransport,
+                    default_class=session_entity_types_grpc_transport.SessionEntityTypesGrpcTransport,
+                    address=api_endpoint,
                 )
             else:
                 if credentials:
                     raise ValueError(
-                        'Received both a transport instance and '
-                        'credentials; these are mutually exclusive.')
+                        "Received both a transport instance and "
+                        "credentials; these are mutually exclusive."
+                    )
                 self.transport = transport
-        self.transport = session_entity_types_grpc_transport.SessionEntityTypesGrpcTransport(
-            address=self.SERVICE_ADDRESS,
-            channel=channel,
-            credentials=credentials,
-        )
+        else:
+            self.transport = session_entity_types_grpc_transport.SessionEntityTypesGrpcTransport(
+                address=api_endpoint, channel=channel, credentials=credentials
+            )
 
         if client_info is None:
-            client_info = (
-                google.api_core.gapic_v1.client_info.DEFAULT_CLIENT_INFO)
-        client_info.gapic_version = _GAPIC_LIBRARY_VERSION
+            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
+                gapic_version=_GAPIC_LIBRARY_VERSION
+            )
+        else:
+            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
         self._client_info = client_info
 
         # Parse out the default settings for retry and timeout for each RPC
@@ -189,7 +223,8 @@ class SessionEntityTypesClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config['interfaces'][self._INTERFACE_NAME], )
+            client_config["interfaces"][self._INTERFACE_NAME]
+        )
 
         # Save a dictionary of cached API call functions.
         # These are the actual callables which invoke the proper
@@ -199,15 +234,20 @@ class SessionEntityTypesClient(object):
 
     # Service calls
     def list_session_entity_types(
-            self,
-            parent,
-            page_size=None,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        parent,
+        page_size=None,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Returns the list of all session entity types in the specified session.
 
+        This method doesn't work with Google Assistant integration.
+        Contact Dialogflow support if you need to use session entities
+        with Google Assistant integration.
+
         Example:
             >>> import dialogflow_v2
             >>>
@@ -224,22 +264,26 @@ class SessionEntityTypesClient(object):
             >>> # Alternatively:
             >>>
             >>> # Iterate over results one page at a time
-            >>> for page in client.list_session_entity_types(parent, options=CallOptions(page_token=INITIAL_PAGE)):
+            >>> for page in client.list_session_entity_types(parent).pages:
             ...     for element in page:
             ...         # process element
             ...         pass
 
         Args:
-            parent (str): Required. The session to list all session entity types from.
-                Format: ``projects/<Project ID>/agent/sessions/<Session ID>``.
+            parent (str): Required. The session to list all session entity types from. Format:
+                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/ sessions/<Session ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             page_size (int): The maximum number of resources contained in the
                 underlying API response. If page streaming is performed per-
                 resource, this parameter does not affect the return value. If page
                 streaming is performed per-page, this determines the maximum number
                 of resources in a page.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -247,10 +291,10 @@ class SessionEntityTypesClient(object):
                 that is provided to the method.
 
         Returns:
-            A :class:`~google.gax.PageIterator` instance. By default, this
-            is an iterable of :class:`~google.cloud.dialogflow_v2.types.SessionEntityType` instances.
-            This object can also be configured to iterate over the pages
-            of the response through the `options` parameter.
+            A :class:`~google.api_core.page_iterator.PageIterator` instance.
+            An iterable of :class:`~google.cloud.dialogflow_v2.types.SessionEntityType` instances.
+            You can also iterate over the pages of the response
+            using its `pages` property.
 
         Raises:
             google.api_core.exceptions.GoogleAPICallError: If the request
@@ -260,44 +304,61 @@ class SessionEntityTypesClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'list_session_entity_types' not in self._inner_api_calls:
+        if "list_session_entity_types" not in self._inner_api_calls:
             self._inner_api_calls[
-                'list_session_entity_types'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.list_session_entity_types,
-                    default_retry=self._method_configs[
-                        'ListSessionEntityTypes'].retry,
-                    default_timeout=self._method_configs[
-                        'ListSessionEntityTypes'].timeout,
-                    client_info=self._client_info,
-                )
+                "list_session_entity_types"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.list_session_entity_types,
+                default_retry=self._method_configs["ListSessionEntityTypes"].retry,
+                default_timeout=self._method_configs["ListSessionEntityTypes"].timeout,
+                client_info=self._client_info,
+            )
 
         request = session_entity_type_pb2.ListSessionEntityTypesRequest(
-            parent=parent,
-            page_size=page_size,
+            parent=parent, page_size=page_size
         )
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("parent", parent)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
         iterator = google.api_core.page_iterator.GRPCIterator(
             client=None,
             method=functools.partial(
-                self._inner_api_calls['list_session_entity_types'],
+                self._inner_api_calls["list_session_entity_types"],
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata),
+                metadata=metadata,
+            ),
             request=request,
-            items_field='session_entity_types',
-            request_token_field='page_token',
-            response_token_field='next_page_token',
+            items_field="session_entity_types",
+            request_token_field="page_token",
+            response_token_field="next_page_token",
         )
         return iterator
 
     def get_session_entity_type(
-            self,
-            name,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        name,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Retrieves the specified session entity type.
 
+        This method doesn't work with Google Assistant integration.
+        Contact Dialogflow support if you need to use session entities
+        with Google Assistant integration.
+
         Example:
             >>> import dialogflow_v2
             >>>
@@ -309,11 +370,15 @@ class SessionEntityTypesClient(object):
 
         Args:
             name (str): Required. The name of the session entity type. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type
-                Display Name>``.
+                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``
+                or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -331,32 +396,52 @@ class SessionEntityTypesClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'get_session_entity_type' not in self._inner_api_calls:
+        if "get_session_entity_type" not in self._inner_api_calls:
             self._inner_api_calls[
-                'get_session_entity_type'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.get_session_entity_type,
-                    default_retry=self._method_configs['GetSessionEntityType']
-                    .retry,
-                    default_timeout=self._method_configs[
-                        'GetSessionEntityType'].timeout,
-                    client_info=self._client_info,
-                )
+                "get_session_entity_type"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.get_session_entity_type,
+                default_retry=self._method_configs["GetSessionEntityType"].retry,
+                default_timeout=self._method_configs["GetSessionEntityType"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = session_entity_type_pb2.GetSessionEntityTypeRequest(
-            name=name, )
-        return self._inner_api_calls['get_session_entity_type'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        request = session_entity_type_pb2.GetSessionEntityTypeRequest(name=name)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("name", name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        return self._inner_api_calls["get_session_entity_type"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
 
     def create_session_entity_type(
-            self,
-            parent,
-            session_entity_type,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        parent,
+        session_entity_type,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Creates a session entity type.
 
+        If the specified session entity type already exists, overrides the session
+        entity type.
+
+        This method doesn't work with Google Assistant integration.
+        Contact Dialogflow support if you need to use session entities
+        with Google Assistant integration.
+
         Example:
             >>> import dialogflow_v2
             >>>
@@ -364,20 +449,25 @@ class SessionEntityTypesClient(object):
             >>>
             >>> parent = client.session_path('[PROJECT]', '[SESSION]')
             >>>
-            >>> # TODO: Initialize ``session_entity_type``:
+            >>> # TODO: Initialize `session_entity_type`:
             >>> session_entity_type = {}
             >>>
             >>> response = client.create_session_entity_type(parent, session_entity_type)
 
         Args:
-            parent (str): Required. The session to create a session entity type for.
-                Format: ``projects/<Project ID>/agent/sessions/<Session ID>``.
+            parent (str): Required. The session to create a session entity type for. Format:
+                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/ sessions/<Session ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             session_entity_type (Union[dict, ~google.cloud.dialogflow_v2.types.SessionEntityType]): Required. The session entity type to create.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.SessionEntityType`
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -395,56 +485,73 @@ class SessionEntityTypesClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'create_session_entity_type' not in self._inner_api_calls:
+        if "create_session_entity_type" not in self._inner_api_calls:
             self._inner_api_calls[
-                'create_session_entity_type'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.create_session_entity_type,
-                    default_retry=self._method_configs[
-                        'CreateSessionEntityType'].retry,
-                    default_timeout=self._method_configs[
-                        'CreateSessionEntityType'].timeout,
-                    client_info=self._client_info,
-                )
+                "create_session_entity_type"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.create_session_entity_type,
+                default_retry=self._method_configs["CreateSessionEntityType"].retry,
+                default_timeout=self._method_configs["CreateSessionEntityType"].timeout,
+                client_info=self._client_info,
+            )
 
         request = session_entity_type_pb2.CreateSessionEntityTypeRequest(
-            parent=parent,
-            session_entity_type=session_entity_type,
+            parent=parent, session_entity_type=session_entity_type
+        )
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("parent", parent)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        return self._inner_api_calls["create_session_entity_type"](
+            request, retry=retry, timeout=timeout, metadata=metadata
         )
-        return self._inner_api_calls['create_session_entity_type'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
 
     def update_session_entity_type(
-            self,
-            session_entity_type,
-            update_mask=None,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        session_entity_type,
+        update_mask=None,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Updates the specified session entity type.
 
+        This method doesn't work with Google Assistant integration.
+        Contact Dialogflow support if you need to use session entities
+        with Google Assistant integration.
+
         Example:
             >>> import dialogflow_v2
             >>>
             >>> client = dialogflow_v2.SessionEntityTypesClient()
             >>>
-            >>> # TODO: Initialize ``session_entity_type``:
+            >>> # TODO: Initialize `session_entity_type`:
             >>> session_entity_type = {}
             >>>
             >>> response = client.update_session_entity_type(session_entity_type)
 
         Args:
-            session_entity_type (Union[dict, ~google.cloud.dialogflow_v2.types.SessionEntityType]): Required. The entity type to update. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type
-                Display Name>``.
+            session_entity_type (Union[dict, ~google.cloud.dialogflow_v2.types.SessionEntityType]): Required. The session entity type to update.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.SessionEntityType`
             update_mask (Union[dict, ~google.cloud.dialogflow_v2.types.FieldMask]): Optional. The mask to control which fields get updated.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2.types.FieldMask`
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -462,33 +569,50 @@ class SessionEntityTypesClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'update_session_entity_type' not in self._inner_api_calls:
+        if "update_session_entity_type" not in self._inner_api_calls:
             self._inner_api_calls[
-                'update_session_entity_type'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.update_session_entity_type,
-                    default_retry=self._method_configs[
-                        'UpdateSessionEntityType'].retry,
-                    default_timeout=self._method_configs[
-                        'UpdateSessionEntityType'].timeout,
-                    client_info=self._client_info,
-                )
+                "update_session_entity_type"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.update_session_entity_type,
+                default_retry=self._method_configs["UpdateSessionEntityType"].retry,
+                default_timeout=self._method_configs["UpdateSessionEntityType"].timeout,
+                client_info=self._client_info,
+            )
 
         request = session_entity_type_pb2.UpdateSessionEntityTypeRequest(
-            session_entity_type=session_entity_type,
-            update_mask=update_mask,
+            session_entity_type=session_entity_type, update_mask=update_mask
+        )
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("session_entity_type.name", session_entity_type.name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        return self._inner_api_calls["update_session_entity_type"](
+            request, retry=retry, timeout=timeout, metadata=metadata
         )
-        return self._inner_api_calls['update_session_entity_type'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
 
     def delete_session_entity_type(
-            self,
-            name,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        name,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Deletes the specified session entity type.
 
+        This method doesn't work with Google Assistant integration.
+        Contact Dialogflow support if you need to use session entities
+        with Google Assistant integration.
+
         Example:
             >>> import dialogflow_v2
             >>>
@@ -500,11 +624,15 @@ class SessionEntityTypesClient(object):
 
         Args:
             name (str): Required. The name of the entity type to delete. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type
-                Display Name>``.
+                ``projects/<Project ID>/agent/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``
+                or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>/entityTypes/<Entity Type Display Name>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -519,18 +647,30 @@ class SessionEntityTypesClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'delete_session_entity_type' not in self._inner_api_calls:
+        if "delete_session_entity_type" not in self._inner_api_calls:
             self._inner_api_calls[
-                'delete_session_entity_type'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.delete_session_entity_type,
-                    default_retry=self._method_configs[
-                        'DeleteSessionEntityType'].retry,
-                    default_timeout=self._method_configs[
-                        'DeleteSessionEntityType'].timeout,
-                    client_info=self._client_info,
-                )
+                "delete_session_entity_type"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.delete_session_entity_type,
+                default_retry=self._method_configs["DeleteSessionEntityType"].retry,
+                default_timeout=self._method_configs["DeleteSessionEntityType"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = session_entity_type_pb2.DeleteSessionEntityTypeRequest(
-            name=name, )
-        self._inner_api_calls['delete_session_entity_type'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        request = session_entity_type_pb2.DeleteSessionEntityTypeRequest(name=name)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("name", name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        self._inner_api_calls["delete_session_entity_type"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
