@@ -1,4 +1,6 @@
-# Copyright 2018 Google LLC
+# -*- coding: utf-8 -*-
+#
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,6 +13,7 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 """Accesses the google.cloud.dialogflow.v2beta1 Contexts API."""
 
 import functools
@@ -18,9 +21,11 @@ import pkg_resources
 import warnings
 
 from google.oauth2 import service_account
+import google.api_core.client_options
 import google.api_core.gapic_v1.client_info
 import google.api_core.gapic_v1.config
 import google.api_core.gapic_v1.method
+import google.api_core.gapic_v1.routing_header
 import google.api_core.grpc_helpers
 import google.api_core.page_iterator
 import google.api_core.path_template
@@ -33,42 +38,42 @@ from dialogflow_v2beta1.proto import agent_pb2
 from dialogflow_v2beta1.proto import agent_pb2_grpc
 from dialogflow_v2beta1.proto import context_pb2
 from dialogflow_v2beta1.proto import context_pb2_grpc
+from dialogflow_v2beta1.proto import validation_result_pb2
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2
 from google.protobuf import field_mask_pb2
 from google.protobuf import struct_pb2
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
-    'dialogflow', ).version
+
+_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class ContextsClient(object):
     """
-    A context represents additional information included with user input or with
-    an intent returned by the Dialogflow API. Contexts are helpful for
-    differentiating user input which may be vague or have a different meaning
-    depending on additional details from your application such as user setting
-    and preferences, previous user input, where the user is in your application,
-    geographic location, and so on.
+    A context represents additional information included with user input or
+    with an intent returned by the Dialogflow API. Contexts are helpful for
+    differentiating user input which may be vague or have a different
+    meaning depending on additional details from your application such as
+    user setting and preferences, previous user input, where the user is in
+    your application, geographic location, and so on.
 
-    You can include contexts as input parameters of a
-    ``DetectIntent`` (or
-    ``StreamingDetectIntent``) request,
-    or as output contexts included in the returned intent.
-    Contexts expire when an intent is matched, after the number of ``DetectIntent``
-    requests specified by the ``lifespan_count`` parameter, or after 10 minutes
-    if no intents are matched for a ``DetectIntent`` request.
+    You can include contexts as input parameters of a ``DetectIntent`` (or
+    ``StreamingDetectIntent``) request, or as output contexts included in
+    the returned intent. Contexts expire when an intent is matched, after
+    the number of ``DetectIntent`` requests specified by the
+    ``lifespan_count`` parameter, or after 20 minutes if no intents are
+    matched for a ``DetectIntent`` request.
 
-    For more information about contexts, see the
-    `Dialogflow documentation <https://dialogflow.com/docs/contexts>`__.
+    For more information about contexts, see the `Dialogflow
+    documentation <https://cloud.google.com/dialogflow/docs/contexts-overview>`__.
     """
 
-    SERVICE_ADDRESS = 'dialogflow.googleapis.com:443'
+    SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
 
     # The name of the interface for this client. This is the key used to
     # find the method configuration in the client_config dictionary.
-    _INTERFACE_NAME = 'google.cloud.dialogflow.v2beta1.Contexts'
+    _INTERFACE_NAME = "google.cloud.dialogflow.v2beta1.Contexts"
 
     @classmethod
     def from_service_account_file(cls, filename, *args, **kwargs):
@@ -84,27 +89,39 @@ class ContextsClient(object):
         Returns:
             dialogflow_v2beta1.ContextsClient: The constructed client.
         """
-        credentials = service_account.Credentials.from_service_account_file(
-            filename)
-        kwargs['credentials'] = credentials
+        credentials = service_account.Credentials.from_service_account_file(filename)
+        kwargs["credentials"] = credentials
         return cls(*args, **kwargs)
 
     from_service_account_json = from_service_account_file
 
     @classmethod
-    def session_path(cls, project, session):
-        """Return a fully-qualified session string."""
+    def context_path(cls, project, session, context):
+        """Return a fully-qualified context string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/sessions/{session}',
+            "projects/{project}/agent/sessions/{session}/contexts/{context}",
             project=project,
             session=session,
+            context=context,
+        )
+
+    @classmethod
+    def environment_context_path(cls, project, environment, user, session, context):
+        """Return a fully-qualified environment_context string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}",
+            project=project,
+            environment=environment,
+            user=user,
+            session=session,
+            context=context,
         )
 
     @classmethod
     def environment_session_path(cls, project, environment, user, session):
         """Return a fully-qualified environment_session string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}',
+            "projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}",
             project=project,
             environment=environment,
             user=user,
@@ -112,34 +129,23 @@ class ContextsClient(object):
         )
 
     @classmethod
-    def context_path(cls, project, session, context):
-        """Return a fully-qualified context string."""
+    def session_path(cls, project, session):
+        """Return a fully-qualified session string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/sessions/{session}/contexts/{context}',
+            "projects/{project}/agent/sessions/{session}",
             project=project,
             session=session,
-            context=context,
         )
 
-    @classmethod
-    def environment_context_path(cls, project, environment, user, session,
-                                 context):
-        """Return a fully-qualified environment_context string."""
-        return google.api_core.path_template.expand(
-            'projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}/contexts/{context}',
-            project=project,
-            environment=environment,
-            user=user,
-            session=session,
-            context=context,
-        )
-
-    def __init__(self,
-                 transport=None,
-                 channel=None,
-                 credentials=None,
-                 client_config=contexts_client_config.config,
-                 client_info=None):
+    def __init__(
+        self,
+        transport=None,
+        channel=None,
+        credentials=None,
+        client_config=None,
+        client_info=None,
+        client_options=None,
+    ):
         """Constructor.
 
         Args:
@@ -169,15 +175,35 @@ class ContextsClient(object):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
+                Client options used to set user options on the client. API Endpoint
+                should be set through client_options.
         """
         # Raise deprecation warnings for things we want to go away.
-        if client_config:
-            warnings.warn('The `client_config` argument is deprecated.',
-                          PendingDeprecationWarning)
+        if client_config is not None:
+            warnings.warn(
+                "The `client_config` argument is deprecated.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+        else:
+            client_config = contexts_client_config.config
+
         if channel:
             warnings.warn(
-                'The `channel` argument is deprecated; use '
-                '`transport` instead.', PendingDeprecationWarning)
+                "The `channel` argument is deprecated; use " "`transport` instead.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+
+        api_endpoint = self.SERVICE_ADDRESS
+        if client_options:
+            if type(client_options) == dict:
+                client_options = google.api_core.client_options.from_dict(
+                    client_options
+                )
+            if client_options.api_endpoint:
+                api_endpoint = client_options.api_endpoint
 
         # Instantiate the transport.
         # The transport is responsible for handling serialization and
@@ -186,25 +212,27 @@ class ContextsClient(object):
             if callable(transport):
                 self.transport = transport(
                     credentials=credentials,
-                    default_class=contexts_grpc_transport.
-                    ContextsGrpcTransport,
+                    default_class=contexts_grpc_transport.ContextsGrpcTransport,
+                    address=api_endpoint,
                 )
             else:
                 if credentials:
                     raise ValueError(
-                        'Received both a transport instance and '
-                        'credentials; these are mutually exclusive.')
+                        "Received both a transport instance and "
+                        "credentials; these are mutually exclusive."
+                    )
                 self.transport = transport
-        self.transport = contexts_grpc_transport.ContextsGrpcTransport(
-            address=self.SERVICE_ADDRESS,
-            channel=channel,
-            credentials=credentials,
-        )
+        else:
+            self.transport = contexts_grpc_transport.ContextsGrpcTransport(
+                address=api_endpoint, channel=channel, credentials=credentials
+            )
 
         if client_info is None:
-            client_info = (
-                google.api_core.gapic_v1.client_info.DEFAULT_CLIENT_INFO)
-        client_info.gapic_version = _GAPIC_LIBRARY_VERSION
+            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
+                gapic_version=_GAPIC_LIBRARY_VERSION
+            )
+        else:
+            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
         self._client_info = client_info
 
         # Parse out the default settings for retry and timeout for each RPC
@@ -212,7 +240,8 @@ class ContextsClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config['interfaces'][self._INTERFACE_NAME], )
+            client_config["interfaces"][self._INTERFACE_NAME]
+        )
 
         # Save a dictionary of cached API call functions.
         # These are the actual callables which invoke the proper
@@ -221,12 +250,14 @@ class ContextsClient(object):
         self._inner_api_calls = {}
 
     # Service calls
-    def list_contexts(self,
-                      parent,
-                      page_size=None,
-                      retry=google.api_core.gapic_v1.method.DEFAULT,
-                      timeout=google.api_core.gapic_v1.method.DEFAULT,
-                      metadata=None):
+    def list_contexts(
+        self,
+        parent,
+        page_size=None,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Returns the list of all contexts in the specified session.
 
@@ -246,26 +277,26 @@ class ContextsClient(object):
             >>> # Alternatively:
             >>>
             >>> # Iterate over results one page at a time
-            >>> for page in client.list_contexts(parent, options=CallOptions(page_token=INITIAL_PAGE)):
+            >>> for page in client.list_contexts(parent).pages:
             ...     for element in page:
             ...         # process element
             ...         pass
 
         Args:
-            parent (str): Required. The session to list all contexts from.
-                Format: ``projects/<Project ID>/agent/sessions/<Session ID>`` or
-                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User
-                ID>/sessions/<Session ID>``. If ``Environment ID`` is not specified, we assume
-                default 'draft' environment. If ``User ID`` is not specified, we assume
-                default '-' user.
+            parent (str): Required. The session to list all contexts from. Format:
+                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             page_size (int): The maximum number of resources contained in the
                 underlying API response. If page streaming is performed per-
                 resource, this parameter does not affect the return value. If page
                 streaming is performed per-page, this determines the maximum number
                 of resources in a page.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -273,10 +304,10 @@ class ContextsClient(object):
                 that is provided to the method.
 
         Returns:
-            A :class:`~google.gax.PageIterator` instance. By default, this
-            is an iterable of :class:`~google.cloud.dialogflow_v2beta1.types.Context` instances.
-            This object can also be configured to iterate over the pages
-            of the response through the `options` parameter.
+            A :class:`~google.api_core.page_iterator.PageIterator` instance.
+            An iterable of :class:`~google.cloud.dialogflow_v2beta1.types.Context` instances.
+            You can also iterate over the pages of the response
+            using its `pages` property.
 
         Raises:
             google.api_core.exceptions.GoogleAPICallError: If the request
@@ -286,39 +317,52 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'list_contexts' not in self._inner_api_calls:
+        if "list_contexts" not in self._inner_api_calls:
             self._inner_api_calls[
-                'list_contexts'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.list_contexts,
-                    default_retry=self._method_configs['ListContexts'].retry,
-                    default_timeout=self._method_configs['ListContexts']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "list_contexts"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.list_contexts,
+                default_retry=self._method_configs["ListContexts"].retry,
+                default_timeout=self._method_configs["ListContexts"].timeout,
+                client_info=self._client_info,
+            )
+
+        request = context_pb2.ListContextsRequest(parent=parent, page_size=page_size)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("parent", parent)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
 
-        request = context_pb2.ListContextsRequest(
-            parent=parent,
-            page_size=page_size,
-        )
         iterator = google.api_core.page_iterator.GRPCIterator(
             client=None,
             method=functools.partial(
-                self._inner_api_calls['list_contexts'],
+                self._inner_api_calls["list_contexts"],
                 retry=retry,
                 timeout=timeout,
-                metadata=metadata),
+                metadata=metadata,
+            ),
             request=request,
-            items_field='contexts',
-            request_token_field='page_token',
-            response_token_field='next_page_token',
+            items_field="contexts",
+            request_token_field="page_token",
+            response_token_field="next_page_token",
         )
         return iterator
 
-    def get_context(self,
-                    name,
-                    retry=google.api_core.gapic_v1.method.DEFAULT,
-                    timeout=google.api_core.gapic_v1.method.DEFAULT,
-                    metadata=None):
+    def get_context(
+        self,
+        name,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Retrieves the specified context.
 
@@ -334,13 +378,14 @@ class ContextsClient(object):
         Args:
             name (str): Required. The name of the context. Format:
                 ``projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>``
-                or ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User
-                ID>/sessions/<Session ID>/contexts/<Context ID>``. If ``Environment ID`` is
-                not specified, we assume default 'draft' environment. If ``User ID`` is not
-                specified, we assume default '-' user.
+                or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>/contexts/<Context ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -358,28 +403,47 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'get_context' not in self._inner_api_calls:
+        if "get_context" not in self._inner_api_calls:
             self._inner_api_calls[
-                'get_context'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.get_context,
-                    default_retry=self._method_configs['GetContext'].retry,
-                    default_timeout=self._method_configs['GetContext'].timeout,
-                    client_info=self._client_info,
-                )
+                "get_context"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.get_context,
+                default_retry=self._method_configs["GetContext"].retry,
+                default_timeout=self._method_configs["GetContext"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = context_pb2.GetContextRequest(name=name, )
-        return self._inner_api_calls['get_context'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        request = context_pb2.GetContextRequest(name=name)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("name", name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
 
-    def create_context(self,
-                       parent,
-                       context,
-                       retry=google.api_core.gapic_v1.method.DEFAULT,
-                       timeout=google.api_core.gapic_v1.method.DEFAULT,
-                       metadata=None):
+        return self._inner_api_calls["get_context"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
+
+    def create_context(
+        self,
+        parent,
+        context,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Creates a context.
 
+        If the specified context already exists, overrides the context.
+
         Example:
             >>> import dialogflow_v2beta1
             >>>
@@ -387,24 +451,25 @@ class ContextsClient(object):
             >>>
             >>> parent = client.session_path('[PROJECT]', '[SESSION]')
             >>>
-            >>> # TODO: Initialize ``context``:
+            >>> # TODO: Initialize `context`:
             >>> context = {}
             >>>
             >>> response = client.create_context(parent, context)
 
         Args:
-            parent (str): Required. The session to create a context for.
-                Format: ``projects/<Project ID>/agent/sessions/<Session ID>`` or
-                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User
-                ID>/sessions/<Session ID>``. If ``Environment ID`` is not specified, we assume
-                default 'draft' environment. If ``User ID`` is not specified, we assume
-                default '-' user.
+            parent (str): Required. The session to create a context for. Format:
+                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             context (Union[dict, ~google.cloud.dialogflow_v2beta1.types.Context]): Required. The context to create.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.Context`
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -422,29 +487,42 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'create_context' not in self._inner_api_calls:
+        if "create_context" not in self._inner_api_calls:
             self._inner_api_calls[
-                'create_context'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.create_context,
-                    default_retry=self._method_configs['CreateContext'].retry,
-                    default_timeout=self._method_configs['CreateContext']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "create_context"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.create_context,
+                default_retry=self._method_configs["CreateContext"].retry,
+                default_timeout=self._method_configs["CreateContext"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = context_pb2.CreateContextRequest(
-            parent=parent,
-            context=context,
+        request = context_pb2.CreateContextRequest(parent=parent, context=context)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("parent", parent)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        return self._inner_api_calls["create_context"](
+            request, retry=retry, timeout=timeout, metadata=metadata
         )
-        return self._inner_api_calls['create_context'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
 
-    def update_context(self,
-                       context,
-                       update_mask=None,
-                       retry=google.api_core.gapic_v1.method.DEFAULT,
-                       timeout=google.api_core.gapic_v1.method.DEFAULT,
-                       metadata=None):
+    def update_context(
+        self,
+        context,
+        update_mask=None,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Updates the specified context.
 
@@ -453,21 +531,23 @@ class ContextsClient(object):
             >>>
             >>> client = dialogflow_v2beta1.ContextsClient()
             >>>
-            >>> # TODO: Initialize ``context``:
+            >>> # TODO: Initialize `context`:
             >>> context = {}
             >>>
             >>> response = client.update_context(context)
 
         Args:
             context (Union[dict, ~google.cloud.dialogflow_v2beta1.types.Context]): Required. The context to update.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.Context`
             update_mask (Union[dict, ~google.cloud.dialogflow_v2beta1.types.FieldMask]): Optional. The mask to control which fields get updated.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.FieldMask`
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -485,28 +565,43 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'update_context' not in self._inner_api_calls:
+        if "update_context" not in self._inner_api_calls:
             self._inner_api_calls[
-                'update_context'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.update_context,
-                    default_retry=self._method_configs['UpdateContext'].retry,
-                    default_timeout=self._method_configs['UpdateContext']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "update_context"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.update_context,
+                default_retry=self._method_configs["UpdateContext"].retry,
+                default_timeout=self._method_configs["UpdateContext"].timeout,
+                client_info=self._client_info,
+            )
 
         request = context_pb2.UpdateContextRequest(
-            context=context,
-            update_mask=update_mask,
+            context=context, update_mask=update_mask
         )
-        return self._inner_api_calls['update_context'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("context.name", context.name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
 
-    def delete_context(self,
-                       name,
-                       retry=google.api_core.gapic_v1.method.DEFAULT,
-                       timeout=google.api_core.gapic_v1.method.DEFAULT,
-                       metadata=None):
+        return self._inner_api_calls["update_context"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
+
+    def delete_context(
+        self,
+        name,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Deletes the specified context.
 
@@ -522,13 +617,14 @@ class ContextsClient(object):
         Args:
             name (str): Required. The name of the context to delete. Format:
                 ``projects/<Project ID>/agent/sessions/<Session ID>/contexts/<Context ID>``
-                or ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User
-                ID>/sessions/<Session ID>/contexts/<Context ID>``. If ``Environment ID`` is
-                not specified, we assume default 'draft' environment. If ``User ID`` is not
-                specified, we assume default '-' user.
+                or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>/contexts/<Context ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -543,25 +639,41 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'delete_context' not in self._inner_api_calls:
+        if "delete_context" not in self._inner_api_calls:
             self._inner_api_calls[
-                'delete_context'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.delete_context,
-                    default_retry=self._method_configs['DeleteContext'].retry,
-                    default_timeout=self._method_configs['DeleteContext']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "delete_context"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.delete_context,
+                default_retry=self._method_configs["DeleteContext"].retry,
+                default_timeout=self._method_configs["DeleteContext"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = context_pb2.DeleteContextRequest(name=name, )
-        self._inner_api_calls['delete_context'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        request = context_pb2.DeleteContextRequest(name=name)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("name", name)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
 
-    def delete_all_contexts(self,
-                            parent,
-                            retry=google.api_core.gapic_v1.method.DEFAULT,
-                            timeout=google.api_core.gapic_v1.method.DEFAULT,
-                            metadata=None):
+        self._inner_api_calls["delete_context"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
+
+    def delete_all_contexts(
+        self,
+        parent,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Deletes all active contexts in the specified session.
 
@@ -576,13 +688,14 @@ class ContextsClient(object):
 
         Args:
             parent (str): Required. The name of the session to delete all contexts from. Format:
-                ``projects/<Project ID>/agent/sessions/<Session ID>`` or ``projects/<Project
-                ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session
-                ID>``. If ``Environment ID`` is not specified we assume default 'draft'
-                environment. If ``User ID`` is not specified, we assume default '-' user.
+                ``projects/<Project ID>/agent/sessions/<Session ID>`` or
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>``.
+                If ``Environment ID`` is not specified we assume default 'draft'
+                environment. If ``User ID`` is not specified, we assume default '-'
+                user.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -597,17 +710,30 @@ class ContextsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'delete_all_contexts' not in self._inner_api_calls:
+        if "delete_all_contexts" not in self._inner_api_calls:
             self._inner_api_calls[
-                'delete_all_contexts'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.delete_all_contexts,
-                    default_retry=self._method_configs[
-                        'DeleteAllContexts'].retry,
-                    default_timeout=self._method_configs['DeleteAllContexts']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "delete_all_contexts"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.delete_all_contexts,
+                default_retry=self._method_configs["DeleteAllContexts"].retry,
+                default_timeout=self._method_configs["DeleteAllContexts"].timeout,
+                client_info=self._client_info,
+            )
 
-        request = context_pb2.DeleteAllContextsRequest(parent=parent, )
-        self._inner_api_calls['delete_all_contexts'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        request = context_pb2.DeleteAllContextsRequest(parent=parent)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("parent", parent)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        self._inner_api_calls["delete_all_contexts"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
