@@ -1,5 +1,6 @@
 # -*- coding: utf-8 -*-
-# Copyright 2018 Google LLC
+#
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -12,15 +13,18 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 """Accesses the google.cloud.dialogflow.v2beta1 Sessions API."""
 
 import pkg_resources
 import warnings
 
 from google.oauth2 import service_account
+import google.api_core.client_options
 import google.api_core.gapic_v1.client_info
 import google.api_core.gapic_v1.config
 import google.api_core.gapic_v1.method
+import google.api_core.gapic_v1.routing_header
 import google.api_core.grpc_helpers
 import google.api_core.path_template
 import grpc
@@ -37,6 +41,7 @@ from dialogflow_v2beta1.proto import document_pb2
 from dialogflow_v2beta1.proto import document_pb2_grpc
 from dialogflow_v2beta1.proto import entity_type_pb2
 from dialogflow_v2beta1.proto import entity_type_pb2_grpc
+from dialogflow_v2beta1.proto import gcs_pb2
 from dialogflow_v2beta1.proto import intent_pb2
 from dialogflow_v2beta1.proto import intent_pb2_grpc
 from dialogflow_v2beta1.proto import knowledge_base_pb2
@@ -45,29 +50,29 @@ from dialogflow_v2beta1.proto import session_entity_type_pb2
 from dialogflow_v2beta1.proto import session_entity_type_pb2_grpc
 from dialogflow_v2beta1.proto import session_pb2
 from dialogflow_v2beta1.proto import session_pb2_grpc
+from dialogflow_v2beta1.proto import validation_result_pb2
 from google.longrunning import operations_pb2
 from google.protobuf import empty_pb2
 from google.protobuf import field_mask_pb2
 from google.protobuf import struct_pb2
 
-_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution(
-    'dialogflow', ).version
+
+_GAPIC_LIBRARY_VERSION = pkg_resources.get_distribution("dialogflow").version
 
 
 class SessionsClient(object):
     """
     A session represents an interaction with a user. You retrieve user input
-    and pass it to the ``DetectIntent`` (or
-    ``StreamingDetectIntent``) method to determine
-    user intent and respond.
+    and pass it to the ``DetectIntent`` (or ``StreamingDetectIntent``)
+    method to determine user intent and respond.
     """
 
-    SERVICE_ADDRESS = 'dialogflow.googleapis.com:443'
+    SERVICE_ADDRESS = "dialogflow.googleapis.com:443"
     """The default address of the service."""
 
     # The name of the interface for this client. This is the key used to
     # find the method configuration in the client_config dictionary.
-    _INTERFACE_NAME = 'google.cloud.dialogflow.v2beta1.Sessions'
+    _INTERFACE_NAME = "google.cloud.dialogflow.v2beta1.Sessions"
 
     @classmethod
     def from_service_account_file(cls, filename, *args, **kwargs):
@@ -83,39 +88,41 @@ class SessionsClient(object):
         Returns:
             dialogflow_v2beta1.SessionsClient: The constructed client.
         """
-        credentials = service_account.Credentials.from_service_account_file(
-            filename)
-        kwargs['credentials'] = credentials
+        credentials = service_account.Credentials.from_service_account_file(filename)
+        kwargs["credentials"] = credentials
         return cls(*args, **kwargs)
 
     from_service_account_json = from_service_account_file
 
-    @classmethod
-    def session_path(cls, project, session):
-        """Return a fully-qualified session string."""
-        return google.api_core.path_template.expand(
-            'projects/{project}/agent/sessions/{session}',
-            project=project,
-            session=session,
-        )
-
     @classmethod
     def environment_session_path(cls, project, environment, user, session):
         """Return a fully-qualified environment_session string."""
         return google.api_core.path_template.expand(
-            'projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}',
+            "projects/{project}/agent/environments/{environment}/users/{user}/sessions/{session}",
             project=project,
             environment=environment,
             user=user,
             session=session,
         )
 
-    def __init__(self,
-                 transport=None,
-                 channel=None,
-                 credentials=None,
-                 client_config=sessions_client_config.config,
-                 client_info=None):
+    @classmethod
+    def session_path(cls, project, session):
+        """Return a fully-qualified session string."""
+        return google.api_core.path_template.expand(
+            "projects/{project}/agent/sessions/{session}",
+            project=project,
+            session=session,
+        )
+
+    def __init__(
+        self,
+        transport=None,
+        channel=None,
+        credentials=None,
+        client_config=None,
+        client_info=None,
+        client_options=None,
+    ):
         """Constructor.
 
         Args:
@@ -145,15 +152,35 @@ class SessionsClient(object):
                 API requests. If ``None``, then default info will be used.
                 Generally, you only need to set this if you're developing
                 your own client library.
+            client_options (Union[dict, google.api_core.client_options.ClientOptions]):
+                Client options used to set user options on the client. API Endpoint
+                should be set through client_options.
         """
         # Raise deprecation warnings for things we want to go away.
-        if client_config:
-            warnings.warn('The `client_config` argument is deprecated.',
-                          PendingDeprecationWarning)
+        if client_config is not None:
+            warnings.warn(
+                "The `client_config` argument is deprecated.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+        else:
+            client_config = sessions_client_config.config
+
         if channel:
             warnings.warn(
-                'The `channel` argument is deprecated; use '
-                '`transport` instead.', PendingDeprecationWarning)
+                "The `channel` argument is deprecated; use " "`transport` instead.",
+                PendingDeprecationWarning,
+                stacklevel=2,
+            )
+
+        api_endpoint = self.SERVICE_ADDRESS
+        if client_options:
+            if type(client_options) == dict:
+                client_options = google.api_core.client_options.from_dict(
+                    client_options
+                )
+            if client_options.api_endpoint:
+                api_endpoint = client_options.api_endpoint
 
         # Instantiate the transport.
         # The transport is responsible for handling serialization and
@@ -162,25 +189,27 @@ class SessionsClient(object):
             if callable(transport):
                 self.transport = transport(
                     credentials=credentials,
-                    default_class=sessions_grpc_transport.
-                    SessionsGrpcTransport,
+                    default_class=sessions_grpc_transport.SessionsGrpcTransport,
+                    address=api_endpoint,
                 )
             else:
                 if credentials:
                     raise ValueError(
-                        'Received both a transport instance and '
-                        'credentials; these are mutually exclusive.')
+                        "Received both a transport instance and "
+                        "credentials; these are mutually exclusive."
+                    )
                 self.transport = transport
-        self.transport = sessions_grpc_transport.SessionsGrpcTransport(
-            address=self.SERVICE_ADDRESS,
-            channel=channel,
-            credentials=credentials,
-        )
+        else:
+            self.transport = sessions_grpc_transport.SessionsGrpcTransport(
+                address=api_endpoint, channel=channel, credentials=credentials
+            )
 
         if client_info is None:
-            client_info = (
-                google.api_core.gapic_v1.client_info.DEFAULT_CLIENT_INFO)
-        client_info.gapic_version = _GAPIC_LIBRARY_VERSION
+            client_info = google.api_core.gapic_v1.client_info.ClientInfo(
+                gapic_version=_GAPIC_LIBRARY_VERSION
+            )
+        else:
+            client_info.gapic_version = _GAPIC_LIBRARY_VERSION
         self._client_info = client_info
 
         # Parse out the default settings for retry and timeout for each RPC
@@ -188,7 +217,8 @@ class SessionsClient(object):
         # (Ordinarily, these are the defaults specified in the `*_config.py`
         # file next to this one.)
         self._method_configs = google.api_core.gapic_v1.config.parse_method_configs(
-            client_config['interfaces'][self._INTERFACE_NAME], )
+            client_config["interfaces"][self._INTERFACE_NAME]
+        )
 
         # Save a dictionary of cached API call functions.
         # These are the actual callables which invoke the proper
@@ -197,15 +227,18 @@ class SessionsClient(object):
         self._inner_api_calls = {}
 
     # Service calls
-    def detect_intent(self,
-                      session,
-                      query_input,
-                      query_params=None,
-                      output_audio_config=None,
-                      input_audio=None,
-                      retry=google.api_core.gapic_v1.method.DEFAULT,
-                      timeout=google.api_core.gapic_v1.method.DEFAULT,
-                      metadata=None):
+    def detect_intent(
+        self,
+        session,
+        query_input,
+        query_params=None,
+        output_audio_config=None,
+        output_audio_config_mask=None,
+        input_audio=None,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Processes a natural language query and returns structured, actionable data
         as a result. This method is not idempotent, because it may cause contexts
@@ -219,7 +252,7 @@ class SessionsClient(object):
             >>>
             >>> session = client.session_path('[PROJECT]', '[SESSION]')
             >>>
-            >>> # TODO: Initialize ``query_input``:
+            >>> # TODO: Initialize `query_input`:
             >>> query_input = {}
             >>>
             >>> response = client.detect_intent(session, query_input)
@@ -227,39 +260,49 @@ class SessionsClient(object):
         Args:
             session (str): Required. The name of the session this query is sent to. Format:
                 ``projects/<Project ID>/agent/sessions/<Session ID>``, or
-                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User
-                ID>/sessions/<Session ID>``. If ``Environment ID`` is not specified, we assume
-                default 'draft' environment. If ``User ID`` is not specified, we are using
-                \"-\". It’s up to the API caller to choose an appropriate ``Session ID`` and
-                ``User Id``. They can be a random numbers or some type of user and session
-                identifiers (preferably hashed). The length of the ``Session ID`` and
-                ``User ID`` must not exceed 36 characters.
+                ``projects/<Project ID>/agent/environments/<Environment ID>/users/<User ID>/sessions/<Session ID>``.
+                If ``Environment ID`` is not specified, we assume default 'draft'
+                environment. If ``User ID`` is not specified, we are using "-". It's up
+                to the API caller to choose an appropriate ``Session ID`` and
+                ``User Id``. They can be a random number or some type of user and
+                session identifiers (preferably hashed). The length of the
+                ``Session ID`` and ``User ID`` must not exceed 36 characters.
             query_input (Union[dict, ~google.cloud.dialogflow_v2beta1.types.QueryInput]): Required. The input specification. It can be set to:
 
                 1.  an audio config
-                ::
-
                     which instructs the speech recognizer how to process the speech audio,
 
                 2.  a conversational query in the form of text, or
 
                 3.  an event that specifies which intent to trigger.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.QueryInput`
-            query_params (Union[dict, ~google.cloud.dialogflow_v2beta1.types.QueryParameters]): Optional. The parameters of this query.
+            query_params (Union[dict, ~google.cloud.dialogflow_v2beta1.types.QueryParameters]): The parameters of this query.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.QueryParameters`
-            output_audio_config (Union[dict, ~google.cloud.dialogflow_v2beta1.types.OutputAudioConfig]): Optional. Instructs the speech synthesizer how to generate the output
+            output_audio_config (Union[dict, ~google.cloud.dialogflow_v2beta1.types.OutputAudioConfig]): Instructs the speech synthesizer how to generate the output
                 audio. If this field is not set and agent-level speech synthesizer is not
                 configured, no output audio is generated.
+
                 If a dict is provided, it must be of the same form as the protobuf
                 message :class:`~google.cloud.dialogflow_v2beta1.types.OutputAudioConfig`
-            input_audio (bytes): Optional. The natural language speech audio to be processed. This field
-                should be populated iff ``query_input`` is set to an input audio config.
-                A single request can contain up to 1 minute of speech audio data.
+            output_audio_config_mask (Union[dict, ~google.cloud.dialogflow_v2beta1.types.FieldMask]): Mask for ``output_audio_config`` indicating which settings in this
+                request-level config should override speech synthesizer settings defined
+                at agent-level.
+
+                If unspecified or empty, ``output_audio_config`` replaces the
+                agent-level config in its entirety.
+
+                If a dict is provided, it must be of the same form as the protobuf
+                message :class:`~google.cloud.dialogflow_v2beta1.types.FieldMask`
+            input_audio (bytes): The natural language speech audio to be processed. This field should be
+                populated iff ``query_input`` is set to an input audio config. A single
+                request can contain up to 1 minute of speech audio data.
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -277,48 +320,62 @@ class SessionsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'detect_intent' not in self._inner_api_calls:
+        if "detect_intent" not in self._inner_api_calls:
             self._inner_api_calls[
-                'detect_intent'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.detect_intent,
-                    default_retry=self._method_configs['DetectIntent'].retry,
-                    default_timeout=self._method_configs['DetectIntent']
-                    .timeout,
-                    client_info=self._client_info,
-                )
+                "detect_intent"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.detect_intent,
+                default_retry=self._method_configs["DetectIntent"].retry,
+                default_timeout=self._method_configs["DetectIntent"].timeout,
+                client_info=self._client_info,
+            )
 
         request = session_pb2.DetectIntentRequest(
             session=session,
             query_input=query_input,
             query_params=query_params,
             output_audio_config=output_audio_config,
+            output_audio_config_mask=output_audio_config_mask,
             input_audio=input_audio,
         )
-        return self._inner_api_calls['detect_intent'](
-            request, retry=retry, timeout=timeout, metadata=metadata)
+        if metadata is None:
+            metadata = []
+        metadata = list(metadata)
+        try:
+            routing_header = [("session", session)]
+        except AttributeError:
+            pass
+        else:
+            routing_metadata = google.api_core.gapic_v1.routing_header.to_grpc_metadata(
+                routing_header
+            )
+            metadata.append(routing_metadata)
+
+        return self._inner_api_calls["detect_intent"](
+            request, retry=retry, timeout=timeout, metadata=metadata
+        )
 
     def streaming_detect_intent(
-            self,
-            requests,
-            retry=google.api_core.gapic_v1.method.DEFAULT,
-            timeout=google.api_core.gapic_v1.method.DEFAULT,
-            metadata=None):
+        self,
+        requests,
+        retry=google.api_core.gapic_v1.method.DEFAULT,
+        timeout=google.api_core.gapic_v1.method.DEFAULT,
+        metadata=None,
+    ):
         """
         Processes a natural language query in audio format in a streaming fashion
         and returns structured, actionable data as a result. This method is only
         available via the gRPC API (not REST).
 
-        EXPERIMENTAL: This method interface might change in the future.
-
         Example:
             >>> import dialogflow_v2beta1
             >>>
             >>> client = dialogflow_v2beta1.SessionsClient()
             >>>
-            >>> # TODO: Initialize ``session``:
+            >>> # TODO: Initialize `session`:
             >>> session = ''
             >>>
-            >>> # TODO: Initialize ``query_input``:
+            >>> # TODO: Initialize `query_input`:
             >>> query_input = {}
             >>> request = {'session': session, 'query_input': query_input}
             >>>
@@ -331,8 +388,8 @@ class SessionsClient(object):
             requests (iterator[dict|google.cloud.dialogflow_v2beta1.proto.session_pb2.StreamingDetectIntentRequest]): The input objects. If a dict is provided, it must be of the
                 same form as the protobuf message :class:`~google.cloud.dialogflow_v2beta1.types.StreamingDetectIntentRequest`
             retry (Optional[google.api_core.retry.Retry]):  A retry object used
-                to retry requests. If ``None`` is specified, requests will not
-                be retried.
+                to retry requests. If ``None`` is specified, requests will
+                be retried using a default configuration.
             timeout (Optional[float]): The amount of time, in seconds, to wait
                 for the request to complete. Note that if ``retry`` is
                 specified, the timeout applies to each individual attempt.
@@ -350,16 +407,16 @@ class SessionsClient(object):
             ValueError: If the parameters are invalid.
         """
         # Wrap the transport method to add retry and timeout logic.
-        if 'streaming_detect_intent' not in self._inner_api_calls:
+        if "streaming_detect_intent" not in self._inner_api_calls:
             self._inner_api_calls[
-                'streaming_detect_intent'] = google.api_core.gapic_v1.method.wrap_method(
-                    self.transport.streaming_detect_intent,
-                    default_retry=self._method_configs['StreamingDetectIntent']
-                    .retry,
-                    default_timeout=self._method_configs[
-                        'StreamingDetectIntent'].timeout,
-                    client_info=self._client_info,
-                )
+                "streaming_detect_intent"
+            ] = google.api_core.gapic_v1.method.wrap_method(
+                self.transport.streaming_detect_intent,
+                default_retry=self._method_configs["StreamingDetectIntent"].retry,
+                default_timeout=self._method_configs["StreamingDetectIntent"].timeout,
+                client_info=self._client_info,
+            )
 
-        return self._inner_api_calls['streaming_detect_intent'](
-            requests, retry=retry, timeout=timeout, metadata=metadata)
+        return self._inner_api_calls["streaming_detect_intent"](
+            requests, retry=retry, timeout=timeout, metadata=metadata
+        )
