@@ -3,7 +3,7 @@ config = {
         "google.cloud.dialogflow.v2beta1.Sessions": {
             "retry_codes": {
                 "idempotent": ["DEADLINE_EXCEEDED", "UNAVAILABLE"],
-                "non_idempotent": []
+                "non_idempotent": [],
             },
             "retry_params": {
                 "default": {
@@ -13,21 +13,21 @@ config = {
                     "initial_rpc_timeout_millis": 20000,
                     "rpc_timeout_multiplier": 1.0,
                     "max_rpc_timeout_millis": 20000,
-                    "total_timeout_millis": 600000
+                    "total_timeout_millis": 600000,
                 }
             },
             "methods": {
                 "DetectIntent": {
                     "timeout_millis": 220000,
                     "retry_codes_name": "non_idempotent",
-                    "retry_params_name": "default"
+                    "retry_params_name": "default",
                 },
                 "StreamingDetectIntent": {
                     "timeout_millis": 220000,
                     "retry_codes_name": "non_idempotent",
-                    "retry_params_name": "default"
-                }
-            }
+                    "retry_params_name": "default",
+                },
+            },
         }
     }
 }
