@@ -1,4 +1,6 @@
-# Copyright 2018 Google LLC
+# -*- coding: utf-8 -*-
+#
+# Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -11,8 +13,10 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+
 """Unit tests."""
 
+import mock
 import pytest
 
 from google.rpc import status_pb2
@@ -51,10 +55,7 @@ class ChannelStub(object):
         self.responses = responses
         self.requests = []
 
-    def unary_unary(self,
-                    method,
-                    request_serializer=None,
-                    response_deserializer=None):
+    def unary_unary(self, method, request_serializer=None, response_deserializer=None):
         return MultiCallableStub(method, self)
 
 
@@ -65,22 +66,24 @@ class CustomException(Exception):
 class TestEntityTypesClient(object):
     def test_list_entity_types(self):
         # Setup Expected Response
-        next_page_token = ''
+        next_page_token = ""
         entity_types_element = {}
         entity_types = [entity_types_element]
         expected_response = {
-            'next_page_token': next_page_token,
-            'entity_types': entity_types
+            "next_page_token": next_page_token,
+            "entity_types": entity_types,
         }
-        expected_response = entity_type_pb2.ListEntityTypesResponse(
-            **expected_response)
+        expected_response = entity_type_pb2.ListEntityTypesResponse(**expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[expected_response])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
 
         paged_list_response = client.list_entity_types(parent)
         resources = list(paged_list_response)
@@ -89,17 +92,19 @@ class TestEntityTypesClient(object):
         assert expected_response.entity_types[0] == resources[0]
 
         assert len(channel.requests) == 1
-        expected_request = entity_type_pb2.ListEntityTypesRequest(
-            parent=parent)
+        expected_request = entity_type_pb2.ListEntityTypesRequest(parent=parent)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
     def test_list_entity_types_exception(self):
         channel = ChannelStub(responses=[CustomException()])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
 
         paged_list_response = client.list_entity_types(parent)
         with pytest.raises(CustomException):
@@ -107,17 +112,25 @@ class TestEntityTypesClient(object):
 
     def test_get_entity_type(self):
         # Setup Expected Response
-        name_2 = 'name2-1052831874'
-        display_name = 'displayName1615086568'
-        expected_response = {'name': name_2, 'display_name': display_name}
+        name_2 = "name2-1052831874"
+        display_name = "displayName1615086568"
+        enable_fuzzy_extraction = True
+        expected_response = {
+            "name": name_2,
+            "display_name": display_name,
+            "enable_fuzzy_extraction": enable_fuzzy_extraction,
+        }
         expected_response = entity_type_pb2.EntityType(**expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[expected_response])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
 
         response = client.get_entity_type(name)
         assert expected_response == response
@@ -130,27 +143,38 @@ class TestEntityTypesClient(object):
     def test_get_entity_type_exception(self):
         # Mock the API response
         channel = ChannelStub(responses=[CustomException()])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup request
-        name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
 
         with pytest.raises(CustomException):
             client.get_entity_type(name)
 
     def test_create_entity_type(self):
         # Setup Expected Response
-        name = 'name3373707'
-        display_name = 'displayName1615086568'
-        expected_response = {'name': name, 'display_name': display_name}
+        name = "name3373707"
+        display_name = "displayName1615086568"
+        enable_fuzzy_extraction = True
+        expected_response = {
+            "name": name,
+            "display_name": display_name,
+            "enable_fuzzy_extraction": enable_fuzzy_extraction,
+        }
         expected_response = entity_type_pb2.EntityType(**expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[expected_response])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
         entity_type = {}
 
         response = client.create_entity_type(parent, entity_type)
@@ -158,17 +182,21 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.CreateEntityTypeRequest(
-            parent=parent, entity_type=entity_type)
+            parent=parent, entity_type=entity_type
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
     def test_create_entity_type_exception(self):
         # Mock the API response
         channel = ChannelStub(responses=[CustomException()])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
         entity_type = {}
 
         with pytest.raises(CustomException):
@@ -176,14 +204,22 @@ class TestEntityTypesClient(object):
 
     def test_update_entity_type(self):
         # Setup Expected Response
-        name = 'name3373707'
-        display_name = 'displayName1615086568'
-        expected_response = {'name': name, 'display_name': display_name}
+        name = "name3373707"
+        display_name = "displayName1615086568"
+        enable_fuzzy_extraction = True
+        expected_response = {
+            "name": name,
+            "display_name": display_name,
+            "enable_fuzzy_extraction": enable_fuzzy_extraction,
+        }
         expected_response = entity_type_pb2.EntityType(**expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[expected_response])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
         entity_type = {}
@@ -193,14 +229,18 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.UpdateEntityTypeRequest(
-            entity_type=entity_type)
+            entity_type=entity_type
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
     def test_update_entity_type_exception(self):
         # Mock the API response
         channel = ChannelStub(responses=[CustomException()])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup request
         entity_type = {}
@@ -210,10 +250,13 @@ class TestEntityTypesClient(object):
 
     def test_delete_entity_type(self):
         channel = ChannelStub()
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
 
         client.delete_entity_type(name)
 
@@ -225,10 +268,13 @@ class TestEntityTypesClient(object):
     def test_delete_entity_type_exception(self):
         # Mock the API response
         channel = ChannelStub(responses=[CustomException()])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup request
-        name = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        name = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
 
         with pytest.raises(CustomException):
             client.delete_entity_type(name)
@@ -237,25 +283,29 @@ class TestEntityTypesClient(object):
         # Setup Expected Response
         expected_response = {}
         expected_response = entity_type_pb2.BatchUpdateEntityTypesResponse(
-            **expected_response)
+            **expected_response
+        )
         operation = operations_pb2.Operation(
-            name='operations/test_batch_update_entity_types', done=True)
+            name="operations/test_batch_update_entity_types", done=True
+        )
         operation.response.Pack(expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
 
         response = client.batch_update_entity_types(parent)
         result = response.result()
         assert expected_response == result
 
         assert len(channel.requests) == 1
-        expected_request = entity_type_pb2.BatchUpdateEntityTypesRequest(
-            parent=parent)
+        expected_request = entity_type_pb2.BatchUpdateEntityTypesRequest(parent=parent)
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -263,16 +313,19 @@ class TestEntityTypesClient(object):
         # Setup Response
         error = status_pb2.Status()
         operation = operations_pb2.Operation(
-            name='operations/test_batch_update_entity_types_exception',
-            done=True)
+            name="operations/test_batch_update_entity_types_exception", done=True
+        )
         operation.error.CopyFrom(error)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
 
         response = client.batch_update_entity_types(parent)
         exception = response.exception()
@@ -283,15 +336,19 @@ class TestEntityTypesClient(object):
         expected_response = {}
         expected_response = empty_pb2.Empty(**expected_response)
         operation = operations_pb2.Operation(
-            name='operations/test_batch_delete_entity_types', done=True)
+            name="operations/test_batch_delete_entity_types", done=True
+        )
         operation.response.Pack(expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
         entity_type_names = []
 
         response = client.batch_delete_entity_types(parent, entity_type_names)
@@ -300,7 +357,8 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.BatchDeleteEntityTypesRequest(
-            parent=parent, entity_type_names=entity_type_names)
+            parent=parent, entity_type_names=entity_type_names
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -308,16 +366,19 @@ class TestEntityTypesClient(object):
         # Setup Response
         error = status_pb2.Status()
         operation = operations_pb2.Operation(
-            name='operations/test_batch_delete_entity_types_exception',
-            done=True)
+            name="operations/test_batch_delete_entity_types_exception", done=True
+        )
         operation.error.CopyFrom(error)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.project_agent_path('[PROJECT]')
+        parent = client.project_agent_path("[PROJECT]")
         entity_type_names = []
 
         response = client.batch_delete_entity_types(parent, entity_type_names)
@@ -329,15 +390,19 @@ class TestEntityTypesClient(object):
         expected_response = {}
         expected_response = empty_pb2.Empty(**expected_response)
         operation = operations_pb2.Operation(
-            name='operations/test_batch_create_entities', done=True)
+            name="operations/test_batch_create_entities", done=True
+        )
         operation.response.Pack(expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entities = []
 
         response = client.batch_create_entities(parent, entities)
@@ -346,7 +411,8 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.BatchCreateEntitiesRequest(
-            parent=parent, entities=entities)
+            parent=parent, entities=entities
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -354,15 +420,19 @@ class TestEntityTypesClient(object):
         # Setup Response
         error = status_pb2.Status()
         operation = operations_pb2.Operation(
-            name='operations/test_batch_create_entities_exception', done=True)
+            name="operations/test_batch_create_entities_exception", done=True
+        )
         operation.error.CopyFrom(error)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entities = []
 
         response = client.batch_create_entities(parent, entities)
@@ -374,15 +444,19 @@ class TestEntityTypesClient(object):
         expected_response = {}
         expected_response = empty_pb2.Empty(**expected_response)
         operation = operations_pb2.Operation(
-            name='operations/test_batch_update_entities', done=True)
+            name="operations/test_batch_update_entities", done=True
+        )
         operation.response.Pack(expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entities = []
 
         response = client.batch_update_entities(parent, entities)
@@ -391,7 +465,8 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.BatchUpdateEntitiesRequest(
-            parent=parent, entities=entities)
+            parent=parent, entities=entities
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -399,15 +474,19 @@ class TestEntityTypesClient(object):
         # Setup Response
         error = status_pb2.Status()
         operation = operations_pb2.Operation(
-            name='operations/test_batch_update_entities_exception', done=True)
+            name="operations/test_batch_update_entities_exception", done=True
+        )
         operation.error.CopyFrom(error)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entities = []
 
         response = client.batch_update_entities(parent, entities)
@@ -419,15 +498,19 @@ class TestEntityTypesClient(object):
         expected_response = {}
         expected_response = empty_pb2.Empty(**expected_response)
         operation = operations_pb2.Operation(
-            name='operations/test_batch_delete_entities', done=True)
+            name="operations/test_batch_delete_entities", done=True
+        )
         operation.response.Pack(expected_response)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entity_values = []
 
         response = client.batch_delete_entities(parent, entity_values)
@@ -436,7 +519,8 @@ class TestEntityTypesClient(object):
 
         assert len(channel.requests) == 1
         expected_request = entity_type_pb2.BatchDeleteEntitiesRequest(
-            parent=parent, entity_values=entity_values)
+            parent=parent, entity_values=entity_values
+        )
         actual_request = channel.requests[0][1]
         assert expected_request == actual_request
 
@@ -444,15 +528,19 @@ class TestEntityTypesClient(object):
         # Setup Response
         error = status_pb2.Status()
         operation = operations_pb2.Operation(
-            name='operations/test_batch_delete_entities_exception', done=True)
+            name="operations/test_batch_delete_entities_exception", done=True
+        )
         operation.error.CopyFrom(error)
 
         # Mock the API response
         channel = ChannelStub(responses=[operation])
-        client = dialogflow_v2beta1.EntityTypesClient(channel=channel)
+        patch = mock.patch("google.api_core.grpc_helpers.create_channel")
+        with patch as create_channel:
+            create_channel.return_value = channel
+            client = dialogflow_v2beta1.EntityTypesClient()
 
         # Setup Request
-        parent = client.entity_type_path('[PROJECT]', '[ENTITY_TYPE]')
+        parent = client.entity_type_path("[PROJECT]", "[ENTITY_TYPE]")
         entity_values = []
 
         response = client.batch_delete_entities(parent, entity_values)
